<?php

namespace Teknisa\DF\Modules\Entrada\Factories;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class Dfe18500DocumentosParaComposicaoDeCustosFactory {
    
    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function produtoItemproduto($nrlanctonf, $cdfilial, $nrorg) {
        $sql = "SELECT 
                    P.CDARVPROD,
                    P.NMPRODUTO,
                    IP.QTITEMPROD,
                    IP.VRUNITITEM,
                    IP.VRTOTAITEM
                FROM
                    ITEMPRODUTO IP,
                    PRODUTO P
                WHERE 
                    P.CDPRODUTO     = IP.CDPRODUTO    AND
                    IP.NRLANCTONF   = :P_NRLANCTONF   AND 
                    IP.CDFILIAL     = :P_CDFILIAL     AND
                    IP.NRORG        = :P_NRORG";
            
        $params = array("P_NRLANCTONF"  => $nrlanctonf,
                        "P_CDFILIAL"    => $cdfilial,
                        "P_NRORG"       => $nrorg);
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function insereRateioit($cdfilial, $nrlanctonf, $nrorg, $nrseqitprod, $vrrateio) {
        $sql = "INSERT INTO RATEIOCUSTOIT(
                    CDFILIAL, 
                    NRLANCTONF, 
                    NRORG, 
                    NRSEQITPROD, 
                    VRRATEIO
                ) values 
                (
                    :P_CDFILIAL, 
                    :P_NRLANCTONF, 
                    :P_NRORG, 
                    :P_NRSEQITPROD, 
                    :P_VRRATEIO)";
        
        $params = array("P_CDFILIAL"    => $cdfilial,
                        "P_NRLANCTONF"  => $nrlanctonf,
                        "P_NRORG"       => $nrorg,
                        "P_NRSEQITPROD" => $nrseqitprod,
                        "P_VRRATEIO"    => $vrrateio);
                        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);

    }
    
    public function updateRateioit($cdfilial, $nrlanctonf, $nrorg, $nrseqitprod, $vrrateio) {
        $sql = "UPDATE  RATEIOCUSTOIT 
                    SET  VRRATEIO = :VRRATEIO 
                WHERE   
                    CDFILIAL    = :CDFILIAL     AND 
                    NRLANCTONF  = :NRLANCTONF   AND
                    NRORG       = :NRORG        AND
                    NRSEQITPROD = :NRSEQITPROD";
        
        $params = array("NRLANCTONF"  => $nrlanctonf,
                        "CDFILIAL"    => $cdfilial,
                        "NRORG"       => $nrorg,
                        "NRSEQITPROD" => $nrseqitprod,
                        "VRRATEIO"    => $vrrateio);
                        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);

    }

    public function insereItemNotaFisc($cdfilial, $nrlanctonf, $cdfilialit, $nrlanctonfit, $nrorg) {
        $sql = "SELECT MAX(NRSEQUITNOTA) AS NRSEQUITNOTA FROM ITEMNOTAFISC WHERE CDFILIAL = :P_CDFILIAL AND NRLANCTONF = :P_NRLANCTONF";
        
        $params = array(
            "P_CDFILIAL"        => $cdfilial,
            "P_NRLANCTONF"      => $nrlanctonf
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        $nrseqitem = $std->fetch()["NRSEQUITNOTA"];
        
        if(!$nrseqitem) {
            $nrseqitem = 0;
        }
        else {
            $nrseqitem += 1;
        }
        $nrseqitem = str_pad($nrseqitem, 3, '0', STR_PAD_LEFT);
        
        $sql = "INSERT INTO ITEMNOTAFISC (
                CDFILIAL,
                NRLANCTONF,
                NRSEQUITNOTA,
                CDFILIALIT,
                NRLANCTONFIT,
                NRORG
            ) VALUES (
                :P_CDFILIAL,
                :P_NRLANCTONF,
                :P_NRSEQUITNOTA,
                :P_CDFILIALIT,
                :P_NRLANCTONFIT,
                :P_NRORG
            )";
            
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRLANCTONF" => $nrlanctonf,
            "P_NRSEQUITNOTA" => $nrseqitem,
            "P_CDFILIALIT" => $cdfilialit,
            "P_NRLANCTONFIT" => $nrlanctonfit,
            "P_NRORG" => $nrorg
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteItemnotafisc($cdfilial, $nrlanctonf, $cdfilialit, $nrlanctonfit) {
        
        $sql = "DELETE 
                    ITEMNOTAFISC
                WHERE 
                    CDFILIAL   = :P_CDFILIAL
                    AND NRLANCTONF = :P_NRLANCTONF
                    AND CDFILIALIT = :P_CDFILIALIT
                    AND NRLANCTONFIT = :P_NRLANCTONFIT";
           
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRLANCTONF" => $nrlanctonf,
            "P_CDFILIALIT" => $cdfilialit,
            "P_NRLANCTONFIT" => $nrlanctonfit
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);  
    }
    
    public function getItemNotaFisc($cdfilial, $nrlanctonf, $cdfilialit, $nrlanctonfit) {
        $sql = "SELECT 
                    *
                FROM
                    ITEMNOTAFISC
                WHERE 
                    CDFILIAL      = :P_CDFILIAL     AND
                    NRLANCTONF    = :P_NRLANCTONF   AND
                    CDFILIALIT    = :P_CDFILIALIT   AND
                    NRLANCTONFIT  = :P_NRLANCTONFIT";
            
        $params = array( "P_CDFILIAL" => $cdfilial,
                         "P_NRLANCTONF" => $nrlanctonf,
                         "P_CDFILIALIT" => $cdfilialit,
                         "P_NRLANCTONFIT" => $nrlanctonfit);
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function getVrRateioCustoItTotal($cdfilial, $nrlanctonf) {
        $sql = "SELECT
                    SUM(VRRATEIO) AS VRTOTALRATEIO
                FROM
                    RATEIOCUSTOIT R
                WHERE 
                    R.CDFILIAL = :P_CDFILIAL
                    AND R.NRLANCTONF = :P_NRLANCTONF";
            
        $params = array( "P_CDFILIAL" => $cdfilial,
                         "P_NRLANCTONF" => $nrlanctonf);
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch()["VRTOTALRATEIO"];
    }
    
    public function getValorTotalCustos($cdfilial, $nrlanctonf) {
        $sql = "SELECT
                    SUM(VRNOTAFISC) AS VRTOTALCUSTOS
                FROM
                    NOTAFISCAL      N,
                    RELACRATCUSTONF R
                WHERE
                    N.NRLANCTONF = R.NRLANCTODOCCOMP
                    AND N.CDFILIAL = R.CDFILIDOCCOMP
                    AND R.NRLANCTONF = :P_NRLANCTONF
                    AND R.CDFILIAL = :P_CDFILIAL";
            
                    
        $params = array( "P_CDFILIAL" => $cdfilial,
                         "P_NRLANCTONF" => $nrlanctonf);
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch()["VRTOTALCUSTOS"];
    }
    
    public function getValorTotalItem($cdfilial, $nrlanctonf) {
        $sql = "SELECT 
                    SUM(VRTOTAITEM) as VRTOTALITEM
                FROM 
                     ITEMPRODUTO    I
                WHERE 
                    I.NRLANCTONF = :P_NRLANCTONF
                    AND I.CDFILIAL   = :P_CDFILIAL";
            
                    
        $params = array( "P_CDFILIAL" => $cdfilial,
                         "P_NRLANCTONF" => $nrlanctonf);
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetch();
    }
    
    public function insereRelacratcustonf($cdfilial, $nrlanctonf, $cdfilidoccomp, $nrlanctodoccomp) {
        
        $sql = "INSERT INTO RELACRATCUSTONF  (
                CDFILIAL,
                NRLANCTONF,
                CDFILIDOCCOMP,
                NRLANCTODOCCOMP
            ) VALUES (
                :P_CDFILIAL,
                :P_NRLANCTONF,
                :P_CDFILIDOCCOMP,
                :P_NRLANCTODOCCOMP
            )";
            
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRLANCTONF" => $nrlanctonf,
            "P_CDFILIDOCCOMP" => $cdfilidoccomp,
            "P_NRLANCTODOCCOMP" => $nrlanctodoccomp
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);
    }
    
    public function deleteRelacratcustonf($cdfilial, $nrlanctonf, $cdfilidoccomp, $nrlanctodoccomp) {
        $sql = "DELETE 
                    RELACRATCUSTONF
                WHERE 
                    CDFILIAL   = :P_CDFILIAL
                    AND NRLANCTONF = :P_NRLANCTONF
                    AND CDFILIDOCCOMP = :P_CDFILIDOCCOMP
                    AND NRLANCTODOCCOMP = :P_NRLANCTODOCCOMP";
           
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRLANCTONF" => $nrlanctonf,
            "P_CDFILIDOCCOMP" => $cdfilidoccomp,
            "P_NRLANCTODOCCOMP" => $nrlanctodoccomp
        );
        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);  
        
    }
    
    public function getRateioCustoIt($cdfilial, $nrlanctonf) {
        $sql = "SELECT
                    *
                FROM
                    RATEIOCUSTOIT R
                WHERE 
                    R.CDFILIAL = :P_CDFILIAL
                    AND R.NRLANCTONF = :P_NRLANCTONF";
            
        $params = array( "P_CDFILIAL" => $cdfilial,
                         "P_NRLANCTONF" => $nrlanctonf);
                
        $std = $this->entityManager->getConnection()->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    public function alteraStatusNotafiscal($cdfilial, $nrlanctonf, $nrorg, $idstatus) {
        $sql = "UPDATE  NOTAFISCAL 
                    SET  IDSTATUS = :IDSTATUS 
                WHERE   
                    CDFILIAL    = :CDFILIAL     AND 
                    NRLANCTONF  = :NRLANCTONF   AND
                    NRORG       = :NRORG  ";
        
        $params = array("CDFILIAL"    => $cdfilial,
                        "NRLANCTONF"  => $nrlanctonf,
                        "NRORG"       => $nrorg,
                        "IDSTATUS" => $idstatus);
                        
        $std = $this->entityManager->getConnection()->prepare($sql);
        return $std->execute($params);

    }
}